# SAIL - Utilities
---------------------

[![pipeline status](http://120.26.148.12/gitlab-ci-group/sail-utils/badges/master/pipeline.svg)](http://120.26.148.12/gitlab-ci-group/sail-utils/commits/master)
[![coverage report](http://120.26.148.12/gitlab-ci-group/sail-utils/badges/master/coverage.svg)](http://120.26.148.12/gitlab-ci-group/sail-utils/commits/master)